#!/bin/sh

set -e

# Firefox launcher containing a Profile migration helper for
# temporary profiles used during alpha and beta phases.

# Authors:
#  Alexander Sack <asac@jwsdot.com>
#  Fabien Tassin <fta@sofaraway.org>
#  Steve Langasek <steve.langasek@canonical.com>
#  Chris Coulson <chris.coulson@canonical.com>
# License: GPLv2 or later

PROFILE=$HOME/.mozilla/firefox
MOZ_LIBDIR=/usr/lib/firefox-5.0
NAME=`which $0`
MOZ_APP_LAUNCHER=$NAME
MOZ_SERIES=5.0
MOZ_DISPLAY_NAME="Firefox"
EXE=firefox-bin
MOZ_APP_BASENAME=firefox

export MOZ_APP_LAUNCHER

while [ ! -x $MOZ_LIBDIR/$EXE ] ; do
    if [ -L "$NAME" ] ; then
        NAME=`readlink -f $NAME`
        MOZ_LIBDIR=`dirname $NAME`
    else
       echo "Can't find $MOZ_LIBDIR/$EXE"
       exit 1
    fi
done

LD_LIBRARY_PATH=${MOZ_LIBDIR}:${MOZ_LIBDIR}/plugins${LD_LIBRARY_PATH:+":$LD_LIBRARY_PATH"}
export LD_LIBRARY_PATH

usage () {
    $MOZ_LIBDIR/$EXE -h | sed -e 's,/.*/,,'
    echo
    echo "      -g or --debug          Start within debugger"
    echo "      -d or --debugger       Specify debugger to start with (eg, gdb or valgrind)"
    echo "      -a or --debugger-args  Specify arguments for debugger"
}

moz_debug=0
moz_debugger_args=""
moz_debugger="gdb"

while [ $# -gt 0 ]; do
    case "$1" in
        -h | --help )
            usage
            exit 0
            ;;
        -g | --debug )
            moz_debug=1
            shift
            ;;
        -d | --debugger)
            moz_debugger=$2;
            if [ "${moz_debugger}" != "" ]; then
	      shift 2
            else
              echo "-d requires an argument"
              exit 1
            fi
            ;;
        -a | --debugger-args )
            moz_debugger_args=$2;
            if [ "${moz_debugger_args}" != "" ] ; then
                shift 2
            else
                echo "-a requires an argument"
                exit 1
            fi
            ;;
        -- ) # Stop option processing
            shift
            break
            ;;
        * )
            break
            ;;
    esac
done

if [ -x $MOZ_LIBDIR/xulapp-profilemigrator ] ; then
    RUN_MIGRATOR=0
    if [ ! -d $PROFILE ] ; then
        RUN_MIGRATOR=1
    elif [ -f $PROFILE.last-version ] ; then
        last_series=`cat $PROFILE.last-version`
        if [ $MOZ_SERIES != $last_series ] ; then
            RUN_MIGRATOR=1
        fi
    else
	RUN_MIGRATOR=1
    fi

    if [ "$RUN_MIGRATOR" = "1" ] ; then
        $MOZ_LIBDIR/xulapp-profilemigrator -s $MOZ_SERIES -p $PROFILE -d $MOZ_DISPLAY_NAME -a $MOZ_APP_BASENAME
    fi
fi

if [ $moz_debug -eq 1 ] ; then
    debugger=`which $moz_debugger`
    if [ ! -x $debugger ] ; then
       echo "Invalid debugger"
       exit 1
    fi

    case `basename $debugger` in
       gdb)
         exec $debugger $moz_debugger_args --args $MOZ_LIBDIR/$EXE "$@"
         ;;
       valgrind)
         exec $debugger $moz_debugger_args $MOZ_LIBDIR/$EXE "$@"
         ;;
       *)
         exec $debugger $moz_debugger_args $MOZ_LIBDIR/$EXE "$@"
         ;;
    esac
else
    exec $MOZ_LIBDIR/$EXE "$@"
fi
